@@ -9,7 +9,7 @@ use Carp;
 use Try::Tiny;
 use Data::Dumper;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 register logged_in_user => sub
 {
@@ -803,7 +803,7 @@ Dancer2::Plugin::Auth::YARBAC - Yet Another Role Based Access Control Framework
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -1050,7 +1050,7 @@ attempts by the user with the 'login_failed' param.
 
 =item authenticate_user - Attempts auth and then returns a hashref
 
-  get '/auth/user' => sub
+  get '/auth/user' => sub {
     # Optionally set the realm:
     # my $auth = authenticate_user( { username => params->{username}, 
     #                                 password => params->{password} }, 
@@ -1381,12 +1381,12 @@ returns false.
   get '/create/user' => sub {
     # Optionally use other realm than current logged in user:
     # my $create = create_user( { username => 'Craig', 
-    #                             password => 'iloveyou' }, 
+    #                             password => 'pass' }, 
     #                           { realm => 'admins' } );
     # Oh, and don't ever use that password for real, obviously :)
 
     my $create = create_user( { username => 'Craig', 
-                                password => 'iloveyou' } );
+                                password => 'pass' } );
     if ( $create ) {
         # success
     }
